/*
 * Compile with:
 *   gcc `pkg-config --cflags --libs goocanvas librsvg-2.0` simple-demo.c
 */

#include <stdlib.h>
#include <goocanvas.h>

/* Just include the svg item to ease compilation. */
#include "svg-item.c"

static gboolean on_delete_event      (GtkWidget      *window,
				      GdkEvent       *event,
				      gpointer        unused_data);


int
main (int argc, char *argv[])
{
  GtkWidget *window, *scrolled_win, *canvas;
  GooCanvasItem *root, *item;
  RsvgHandle *svg_handle = NULL;
  GError *error = NULL;

  g_thread_init (NULL);

  /* Initialize GTK+. */
  gtk_set_locale ();
  gtk_init (&argc, &argv);

  /* Create the window and widgets. */
  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_default_size (GTK_WINDOW (window), 640, 600);
  gtk_widget_show (window);
  g_signal_connect (window, "delete_event", (GtkSignalFunc) on_delete_event,
		    NULL);

  scrolled_win = gtk_scrolled_window_new (NULL, NULL);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_win),
				       GTK_SHADOW_IN);
  gtk_widget_show (scrolled_win);
  gtk_container_add (GTK_CONTAINER (window), scrolled_win);

  canvas = goo_canvas_new ();
  gtk_widget_set_size_request (canvas, 600, 450);
  goo_canvas_set_bounds (GOO_CANVAS (canvas), 0, 0, 1000, 1000);
  gtk_widget_show (canvas);
  gtk_container_add (GTK_CONTAINER (scrolled_win), canvas);

  root = goo_canvas_get_root_item (GOO_CANVAS (canvas));

  rsvg_init();
  svg_handle = rsvg_handle_new_from_file ("test.svg", &error);
  item = goo_svg_item_new (root, svg_handle, NULL);
  g_object_unref (svg_handle);

  goo_canvas_item_set_simple_transform (item, 100, 100, 2, 30);

  /* Pass control to the GTK+ main event loop. */
  gtk_main ();

  return 0;
}


/* This is our handler for the "delete-event" signal of the window, which
   is emitted when the 'x' close button is clicked. We just exit here. */
static gboolean
on_delete_event (GtkWidget *window,
		 GdkEvent  *event,
		 gpointer   unused_data)
{
  exit (0);
}
